#
# spec file for package monitoring-plugins-smart
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           monitoring-plugins-smart
Version:        6.14.3
Release:        1.1
Summary:        Check SMART status of a given disk
License:        GPL-3.0-or-later
Group:          System/Monitoring
URL:            https://www.claudiokuenzler.com/nagios-plugins/check_smart.php
#Git-Clone:     https://github.com/Napsty/check_smart.git
Source0:        https://github.com/Napsty/check_smart/archive/refs/tags/%{version}.tar.gz#/check_smart-%{version}.tar.gz
Source1:        usr.lib.nagios.plugins.check_smart
Source3:        monitoring-plugins-smart-README.SUSE
Source4:        monitoring-plugins-smart-rpmlintrc
BuildRequires:  nagios-rpm-macros
BuildRequires:  sudo
Requires:       monitoring-plugins-common
Requires:       smartmontools >= 5.39
Requires:       sudo
Requires:       perl(File::Basename)
Requires:       perl(FindBin)
Requires:       perl(Getopt::Long)
Provides:       nagios-plugins-smart = %{version}-%{release}
Obsoletes:      nagios-plugins-smart < 1.02
BuildArch:      noarch
%if 0%{?suse_version}
Recommends:     apparmor-parser
%endif

%description
This plugin does SMART monitoring both ATA and SCSI disks, has an easy usage
syntax, and automatically produces perfdata for all applicable metrics.

Note:
On older distributions you need a line like
 nagios        ALL=(root) NOPASSWD: /usr/lib/nagios/plugins/check_smart
in /etc/sudoers to run this script as non privileged user.

Since SLES 12/openSUSE 12.1, there is a file
  /etc/sysconfig/sudoers.d/monitoring-plugins-smart
which holds the same content and should be used automatically.

%prep
%setup -q -n check_smart-%{version}
install -m644 %{SOURCE3} README.SUSE

%build

%install
install -D -m755 check_smart.pl %{buildroot}/%{nagios_plugindir}/check_smart
install -D -m644 %{SOURCE1}  %{buildroot}/%{_sysconfdir}/apparmor.d/usr.lib.nagios.plugins.check_smart
%if 0%{?suse_version} > 1130
mkdir -p %{buildroot}/%{_sysconfdir}/sudoers.d
cat >> %{buildroot}/%{_sysconfdir}/sudoers.d/%{name} << EOF
# the next line is needed for %{name} to allow the correct use of smartctl
nagios,icinga ALL=(root) NOPASSWD: %{nagios_plugindir}/check_smart
EOF
%endif

%files
%doc README.SUSE README.md SSD-TBW-Warranty.md
%license COPYING.md
%dir %{nagios_libdir}
%dir %{_sysconfdir}/apparmor.d
%dir %{nagios_plugindir}
%{nagios_plugindir}/check_smart
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.lib.nagios.plugins.check_smart
%if 0%{?suse_version} > 1130
%config(noreplace) %{_sysconfdir}/sudoers.d/%{name}
%endif

%changelog
* Tue Sep 10 2024 Martin Hauke <mardnh@gmx.de>
- Update to 6.14.3
  * Fix performance data format
  * Fix defect_list performance data not showing on SCSI drives
    when no elements in grown defect list, see #99
* Fri Mar 15 2024 Lars Vogdt <lars@linux-schulserver.de>
- update to 6.14.2
  + #97 Fix nvme attribute check-list when auto interface is given
    and device is nvme
* Wed Sep 20 2023 lars@linux-schulserver.de - 6.14.1
- update to 6.14.1
  + Fix default Percent_Lifetime_Remain threshold handling when -w
    is given by @ymartin-ovh , see #93
  + Fix debug output of raw check list when using -l or
    ssd-lifetime, see #94
  + Fix --hide-sn when combined with --debug (the smartctl output
    still showed the serial number), see #94
* Sun Apr 30 2023 lars@linux-schulserver.de - 6.14.0
- Update to 6.14.0
  + Show drive(s) causing the UNKNOWN status when checking multiple
    drives using -g / --global parameter #89
  + Add possibility to hide the drive's serial number in the plugin output
    using --hide-sn #90
  + Check (by default) for high Load Cycle Count of hard drive. Can
    be ignored using --skip-load-cycles parameter #91
- package SSD-TBW-Warranty.md as documentation
- add user icinga to the sudo profile for check_smart - allowing
  icinga to execute the script as well
- follow upstream license change: GPL-3.0-or-later
- package COPYING.md as license file
* Fri Apr 29 2022 lars@linux-schulserver.de - 6.13.0
- Update to 6.13.0
  + Allow skip temperature check, introduces new parameter --skip-temp-check
  + Improved handling of missing or non-executable smartctl command
* Fri Dec 17 2021 lars@linux-schulserver.de - 6.12.2
- Update to 6.12.2:
  + Bugfix when interface parameter was missing in combination
    with -g (#79)
* Mon Dec 13 2021 lars@linux-schulserver.de - 6.12.1
- Update to 6.12.1:
  + Fix regression bug in 6.12.0 (#77)
  + Security fix in trailing path for pseudo-devices (Additional
    anchor for security)
  + Update help
  + Add Erase_Fail_Count_Total to default raw list
  + Fix NVMe perfdata (issue 74)
- encapsulate the recommends to allow building on RHEL based
  distributions
* Fri Nov 19 2021 lars@linux-schulserver.de - 6.11.0
- reduce the sudoers rights for nagios user from using smartctl to
  only call the plugin itself. As the plugin is called with sudo
  rights, the included sudo calls in the plugin will also be executed
  as root and don't cause any problem. As the plugin is only writable
  by root, this forbits the nagios user to execute smartctl with
  arbitrary options (boo#1191671)
- update to 6.11.0
  + Handle dots in NVMe attributes, prioritize (order) alerts
  + Add aacraid devices (6.10.0)
- add rpmlintrc
* Mon May 10 2021 lars@linux-schulserver.de - 6.9.1
- Update to 6.9.1:
  This is a security-release (bsc#1183057)
  + Fixes the regular expression for pseudo-devices under the /dev/bus/N path.
  from 6.9.0
  + Allows using PCI device paths as device name(s) (#64)
  + Introduce new optional parameter -l/--ssd-lifetime) which additionally
    checks SMART attribute "Percent_Lifetime_Remain"
    (available on some SSD drives). (#66 #67)
  from 6.8.0
  + Allow skip self-assessment check (--skip-self-assessment)
  + Add Command_Timeout to default raw list
  from 6.7.1
  + Bugfix to make --warn work (issue #54)
  from 6.7.0
  + Added support for NVMe drives
  from 6.6.1
  + Fix 'deprecation warning on regex with curly brackets' (6.6.1)
  from 6.6.0
  + The feature was requested in #30 . This PR adds the possibility to
    use 3ware,N and cciss,N drives in combination with the
    global -g parameter.
  + Furthermore this PR adjusts the output of the plugin when the -g
    is used in combination with hardware raid controllers. Instead of
    showing the logical device name (/dev/sda for example), the plugin
    will now show the controller with drive number
  from 6.5.0:
  + Add Reported_Uncorrect and Reallocated_Event_Count to default raw list.
  + As of 6.5 the following SMART attributes are by default checked and
    may result in alert when threshold (default 0 is reached):
    'Current_Pending_Sector,Reallocated_Sector_Ct,Program_Fail_Cnt_Total,
    Uncorrectable_Error_Cnt,Offline_Uncorrectable,Runtime_Bad_Block,
    Reported_Uncorrect,Reallocated_Event_Count'
- use _service file (with localrun -> osc service run) and generated
  tarball instead of single file
- remove check_smart.pl
- package README.md
* Thu Oct 31 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 6.4
  - Allow detection of more than 26 devices / issue #5 (rev 5.3)
  - Different ATA vs. SCSI lookup (rev 5.4)
  - Allow script to run outside of nagios plugins dir / wiki url
    update (rev 5.5)
  - Change syntax of -g parameter (regex is now awaited from
    input) (rev 5.6)
  - Fix Use of uninitialized value $device (rev 5.7)
  - Allow multiple devices for interface type megaraid,
    e.g. "megaraid,[1-5]" (rev 5.8)
  - allow type "auto" (rev 5.9)
  - Check selftest log for errors using new parameter -s (rev 5.10)
  - Add exclude list (-e) to ignore certain attributes (5.11)
  - Fix 'Use of uninitialized value' warnings (5.11.1)
  - Add raw check list (-r) and warning thresholds (-w) (6.0)
  - Allow using pseudo bus device /dev/bus/N (6.1)
  - Add device model and serial number in output (6.2)
  - Allow exclusion from perfdata as well (-E) and by attribute
    number (6.3)
  - Remove dependency on utils.pm, add quiet parameter (6.4)
- Drop not longer needed patch:
  * enable_auto_interface.patch (obsolete, type auto was added
    upstream in v5.9).
* Tue Mar  3 2015 lars@linux-schulserver.de
- include <abstractions/user-tmp> in apparmor profile
* Fri Oct 17 2014 coolo@suse.com
- buildrequire sudo to avoid having to package the sudoers directory
  with wrong permissions
* Wed Jul 30 2014 lars@linux-schulserver.de
- package renamed to monitoring-plugins-smart
- update to 5.2:
  + support hardware raids like megaraid (rev 2.0)
  + update help output (rev 2.1)
  + making the plugin work on FreeBSD (rev 3.0)
  + allowing -i sat (SATA on FreeBSD) (rev 3.1)
  + works now with CCISS on FreeBSD (rev 3.2)
  + elements in grown defect list causes warning (rev 3.3)
  + add threshold option "bad" (-b) (rev 4.0)
  + modified help (rev 4.0)
  + bugfix in threshold logic (rev 4.1)
  + bugfix in defect list perfdata (rev 4.2)
  + implemented -g to do a global lookup (rev 5.0)
  + cleanup, merge Jeromes code, perfdata output fix (rev 5.1)
  + Fixed output bug in global check / issue #3 (rev 5.2)
- adapted enable_auto_interface.patch
- removed check_smart-enable_adaptec_raid_controllers.patch
- switched spec file license to SUSE-Public-Domain
* Wed Jun 25 2014 wagner-thomas@gmx.at
- support for dummy interface 'auto'. Using the interface 'auto',
  smartctl will select an appropriate interface by itself.
* Fri Mar 28 2014 lars@linux-schulserver.de
- further enhance the usage documentation (bnc #857441)
- fix license string to follow spdx recommendation
* Mon Jun  4 2012 lars@linux-schulserver.de
- require monitoring-plugins-common
* Wed May 16 2012 lars@linux-schulserver.de
- update to 1.0.1 for 11.4 and beyond - includes a patch to check
  disks behind Adaptec RAID controllers
- added initial Apparmor profile
- added sudoers file for 11.4 and beyond
- added README.SuSE to inform users about Apparmor and sudoers
  files
* Sun Dec 19 2010 lars@linux-schulserver.de
- changed to a better check from monitoringexchange (see URL)
* Fri Aug 20 2010 ro@suse.de
- created package (from nagiosplug/contrib)
